# qosst-sim

<center>

![QOSST Logo](qosst_logo_full.png)

</center>

This project is part of [QOSST](https://github.com/qosst/qosst).

## Features

`qosst-sim` allows to perform some simulations.

## Installation

The module can be installed with the following command:

```console
pip install qosst-sim
```

It is also possible to install it directly from the github repository:

```console
pip install git+https://github.com/qosst/qosst-sim
```

It also possible to clone the repository before and install it with pip or poetry

```console
git clone https://github.com/qosst/qosst-sim
cd qosst-alice
poetry install
pip install .
```

## Documentation

The whole documentation can be found at https://qosst-sim.readthedocs.io/en/latest/

## License

As for all submodules of QOSST, `qosst-sim` is shipped under the [Gnu General Public License v3](https://www.gnu.org/licenses/gpl-3.0.html).

## Contributing

Contribution are more than welcomed, either by reporting issues or proposing merge requests. Please check the contributing section of the [QOSST](https://github.com/qosst/qosst) project fore more information.
